==> navigine_sdk-0.0.1.tar.gz: android/src/main/java/com/navigine/navigine/NaviginePlugin.java <==
package com.navigine.navigine;

import android.content.Context;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;


public class NaviginePlugin implements MethodCallHandler {
    NavigineHelper helper;
    Context context;
    MethodChannel methodChannel;

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "navigine");
        channel.setMethodCallHandler(new NaviginePlugin(registrar.activeContext(), channel));
    }

    NaviginePlugin(Context context, MethodChannel methodChannel) {
        this.context = context;
        this.methodChannel = methodChannel;
        helper = new NavigineHelper(methodChannel);
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        String methodName = call.method;
        switch (methodName) {
            case "initialize":
                result.success(helper.initializeSDK(context, (String) call.argument("userHash"), (String) call.argument("serverUrl")));
                result.success(null);
                break;
            case "loadLocation":
                helper.loadLocation((int) call.argument("locationId"));
                result.success(null);
                break;
            case "startNavigation":
                helper.startNavigation((int) call.argument("mode"));
                result.success(null);
                break;
            case "stopNavigation":
                helper.stopNavigation();
                result.success(null);
                break;
            case "getLocation":
                result.success(helper.getLocation());
                break;
            case "getDeviceInfo":
                result.success(helper.getDeviceInfo());
                break;
            case "getDeviceInfoStream":
                helper.getDeviceInfoStream();
                result.success(null);
                break;
            default:
                result.notImplemented();
                break;
        }
    }


}

==> navigine_sdk-1.1.0.tar.gz: android/src/main/java/com/navigine/navigine/NaviginePlugin.java <==
package com.navigine.navigine;

import android.content.Context;

import com.navigine.naviginesdk.LocationPoint;
import com.navigine.naviginesdk.RoutePath;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

public class NaviginePlugin implements MethodCallHandler {
    NavigineHelper helper;
    Context context;
    MethodChannel methodChannel;

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "navigine_sdk");
        channel.setMethodCallHandler(new NaviginePlugin(registrar.activeContext(), channel));
    }

    NaviginePlugin(Context context, MethodChannel methodChannel) {
        this.context = context;
        this.methodChannel = methodChannel;
        helper = new NavigineHelper(methodChannel);
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        String methodName = call.method;
        switch (methodName) {
            case "initialize":
                result.success(helper.initializeSDK(context, (String) call.argument("userHash"),
                        (String) call.argument("serverUrl")));
                result.success(null);
                break;
            case "loadLocation":
                helper.loadLocation((int) call.argument("locationId"));
                result.success(null);
                break;
            case "startNavigation":
                helper.startNavigation((int) call.argument("mode"));
                result.success(null);
                break;
            case "stopNavigation":
                helper.stopNavigation();
                result.success(null);
                break;
            case "getLocation":
                result.success(helper.getLocation());
                break;
            case "getDeviceInfo":
                result.success(helper.getDeviceInfo());
                break;
            case "getDeviceInfoStream":
                helper.getDeviceInfoStream();
                result.success(null);
                break;
            case "addTarget":
                helper.addTarget(Convert.objectToLocationPoint((Map<String, Object>) call.argument("locationPoint")));
                result.success(null);
                break;
            case "makeRoute":
                LocationPoint point1 = Convert
                        .objectToLocationPoint((Map<String, Object>) call.argument("locationPoint1"));
                LocationPoint point2 = Convert
                        .objectToLocationPoint((Map<String, Object>) call.argument("locationPoint2"));
                RoutePath path = helper.makeRoute(point1, point2);
                result.success(Convert.routePathToObject(path));
                break;
            default:
                result.notImplemented();
                break;
        }
    }

}
